aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/lite/util.h
diff options
context:
space:
mode:
authorGravatar Yu-Cheng Ling <ycling@google.com>2018-09-27 14:25:18 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-09-27 14:30:11 -0700
commitd0397c3314600da0c9cdc300ae87483331d54298 (patch)
tree8ec45f483facaa2219324a19a7f74e38e2e0a5e2 /tensorflow/contrib/lite/util.h
parentcc83067469bc30bba55932c587f31ef68f15792f (diff)
Rename TFLite Eager delegate -> Flex delegate
PiperOrigin-RevId: 214835588
Diffstat (limited to 'tensorflow/contrib/lite/util.h')
-rw-r--r--tensorflow/contrib/lite/util.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tensorflow/contrib/lite/util.h b/tensorflow/contrib/lite/util.h
index 6d81f844f8..31292a6f81 100644
--- a/tensorflow/contrib/lite/util.h
+++ b/tensorflow/contrib/lite/util.h
@@ -26,15 +26,15 @@ limitations under the License.
namespace tflite {
// The prefix of Eager op custom code.
// This will be matched agains the `custom_code` field in `OperatorCode`
// Flatbuffer Table.
// WARNING: This is an experimental API and subject to change.
-constexpr char kEagerCustomCodePrefix[] = "Eager";
+constexpr char kFlexCustomCodePrefix[] = "Flex";
// Checks whether the prefix of the custom name indicates the operation is an
-// Eager operation.
-bool IsEagerOp(const char* custom_name);
+// Flex operation.
+bool IsFlexOp(const char* custom_name);
// Converts a `std::vector` to a `TfLiteIntArray`. The caller takes ownership
// of the returned pointer.
@@ -26,15 +26,15 @@ limitations under the License.
namespace tflite {
-// The prefix of Eager op custom code.
+// The prefix of Flex op custom code.
// This will be matched agains the `custom_code` field in `OperatorCode`
// Flatbuffer Table.